.. automodule:: benker.parsers.ooxml
    :members:
    :undoc-members:
    :show-inheritance:

.. toctree::

   benker.parsers.ooxml.namespaces
   benker.parsers.ooxml.types
   benker.parsers.ooxml.w_pg_sz
   benker.parsers.ooxml.w_shd

